@@ -11,6 +11,7 @@ from .raster_map import *
 from .vector_map import *
 from .roughness_map import read_roughness_map
 from .elevation_map import read_elevation_map
+from .empty import *
 from .weibull_wind_climate import *
 from .wind import (
     wind_speed,
@@ -27,4 +28,5 @@ from .wind_turbine import (
 )
 from .workspace import Workspace
 from .weibull import *
+from .wind_climate import mean_windspeed, power_density
 from . import plot  # Order of imports matters
