@@ -16,6 +16,8 @@ This includes the ability to create bwc datasets both from files and from
 existing data, the ability to calculate common parameters from the bwc object,
 and the ability to write them to the legacy *.tab* format.
 """
+import logging
+
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #    from:
 #        - text file: open_tabfile()
@@ -25,14 +27,14 @@ and the ability to write them to the legacy *.tab* format.
 #
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 from functools import wraps
-import logging
 from pathlib import Path
 
-from lxml import etree
 import numpy as np
 import xarray as xr
+from lxml import etree
 
-from .metadata import _BWC_ATTRS, update_var_attrs, update_history
+from ._validate import create_validator
+from .metadata import _BWC_ATTRS, update_history, update_var_attrs
 from .sector import (
     create_sector_coords,
     create_ws_bin_coords,
@@ -42,15 +44,12 @@ from .spatial import (
     create_dataset,
     crs_are_equal,
     is_point,
-    to_point,
     spatial_stack,
     spatial_unstack,
+    to_point,
 )
-from .wind import wd_to_sector
 from .time_series_wind_climate import ts_validate_wrapper
-
-from ._validate import create_validator
-
+from .wind import wd_to_sector
 
 DATA_VAR_DICT_BWC = {"wsfreq": ["wsbin", "sector"], "wdfreq": ["sector"]}
 
@@ -127,7 +126,14 @@ def wv_count_wrapper(func):
 
 
 def _freqs_to_dataset(
-    wsfreq, wdfreq, wsbins, south_north, west_east, height, crs, **kwargs,
+    wsfreq,
+    wdfreq,
+    wsbins,
+    south_north,
+    west_east,
+    height,
+    crs,
+    **kwargs,
 ):  # pragma: no cover covered_in_public_method
     """
     Makes data variables, coordinates, and attributes ready for
@@ -187,7 +193,12 @@ def _freqs_to_dataset(
     ds["wdfreq"] = (("sector", "point"), wdfreq[:, na])
     ds["wsfreq"] = (("wsbin", "sector", "point"), wsfreq[:, :, na])
 
-    ds = ds.assign_coords({**wscenters.coords, **wdcenters.coords,})
+    ds = ds.assign_coords(
+        {
+            **wscenters.coords,
+            **wdcenters.coords,
+        }
+    )
 
     ds = ds.assign_attrs(kwargs)
 
@@ -933,8 +944,8 @@ def bwc_ws_moment(bwc, n=1.0, bysector=False):
         Array of wind speed moments.
     """
     if bysector:
-        return (bwc.wsfreq * bwc.wsbin ** n).sum(dim=["wsbin"])
-    return (bwc.wdfreq * bwc.wsfreq * bwc.wsbin ** n).sum(dim=["wsbin", "sector"])
+        return (bwc.wsfreq * bwc.wsbin**n).sum(dim=["wsbin"])
+    return (bwc.wdfreq * bwc.wsfreq * bwc.wsbin**n).sum(dim=["wsbin", "sector"])
 
 
 @wv_count_wrapper
@@ -958,7 +969,7 @@ def bwc_kinetic_energy(bwc, air_density=1.225, bysector=False):
     ws_monent: xarray.DataArray
         Array of wind kinetic energy.
     """
-    ke_cen = 0.5 * air_density * bwc.wsbin ** 3.0
+    ke_cen = 0.5 * air_density * bwc.wsbin**3.0
     if bysector:
         return (bwc.wsfreq * ke_cen).sum(dim=["wsbin"])
     return (bwc.wdfreq * ke_cen * bwc.wsfreq).sum(dim=["wsbin", "sector"])
