@@ -9,25 +9,23 @@ NetCDF files. In the future we will also support the ability to read in .gwc
 files.
 """
 
-import logging
-from pathlib import Path
-from functools import wraps
 import re
-from turtle import up
+from pathlib import Path
 
-from lxml import etree
 import numpy as np
 import xarray as xr
+from lxml import etree
+
 from ._validate import create_validator
 from .metadata import (
-    ALL_VARS_META,
     _WEIB_ATTRS,
+    ALL_VARS_META,
     create_coords,
-    update_var_attrs,
     update_history,
+    update_var_attrs,
 )
 from .sector import create_sector_coords
-from .spatial import create_dataset, crs_are_equal, to_point, reproject
+from .spatial import create_dataset, crs_are_equal, reproject, to_point
 
 _GEN_COORDS_META = {
     "gen_height": ALL_VARS_META["gen_height"],
