@@ -13,6 +13,9 @@ Supported objects include:
    3. **cuboid** (..., *height*, *south_north*, *west_east*) this requires regular spacing in the *south_north* and *west_east* dimensions
    4. **raster** (..., *south_north*, *west_east*) this is an internal structure that behaves like a 2D **cuboid**
 """
+from ._cuboid import to_cuboid
+
+# nopycln: file
 from ._point import to_point, to_stacked_point
 from ._raster import to_raster
 from ._struct import (
@@ -23,6 +26,7 @@ from ._struct import (
     is_stacked_point,
     is_vertical,
 )
+from .decorators import stack_then_unstack
 from .spatial import *
 
 __all__ = [
