@@ -19,19 +19,14 @@ from ..geospatial_imports import (
 
 if has_rasterio:
     import rasterio as rio
-    import rasterio.features  # used as rio.features
+    import rasterio.features  # nopycln: import used as rio.features
     from affine import Affine
 
 from ..metadata import _MAP_TYPE_ATTRS, update_history, update_var_attrs
 from ._bbox import BBox
 from ._crs import add_crs, get_crs
-from ._dimensions import (
-    _get_point_dim,
-    _get_spatial_dims,
-    _get_stacked_point_dim,
-    _get_vertical_dim,
-)
-from ._struct import is_cuboid, is_point, is_raster, is_stacked_point, is_vertical
+from ._dimensions import _point_dim, _stacked_point_dim, _vertical_dim, _xy_dims
+from ._struct import is_cuboid, is_point, is_raster, is_stacked_point
 from ._vertical import has_height_coord
 
 
@@ -50,7 +45,7 @@ def _shape(obj):
         (nx, ny)
 
     """
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
     return obj[x_dim].values.size, obj[y_dim].values.size
 
 
@@ -70,7 +65,7 @@ def _internal_bounds(obj):
         (left, bottom, right, top)
 
     """
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
     left, right = obj[x_dim].values[0], obj[x_dim].values[-1]
     bottom, top = obj[y_dim].values[0], obj[y_dim].values[-1]
     return left, bottom, right, top
@@ -224,7 +219,7 @@ def _warp_raster(
         return dst_data
 
     obj = obj.copy()
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
 
     resampling = getattr(rio.enums.Resampling, method)
 
@@ -360,7 +355,7 @@ def _mask_raster(
             + " geopandas.GeoSeries or shapely.geometry.Polygon"
         )
 
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
     nx, ny = _shape(obj)
     transform_ = _transform(obj)
     crs_mask = pyproj.CRS.from_user_input(mask.crs)
@@ -423,7 +418,7 @@ def _clip_to_bbox_raster(obj, bbox):  # pragma: no cover covered_in_public_metho
     """
     obj = obj.copy()
 
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
 
     crs_raster = get_crs(obj)
 
@@ -560,10 +555,10 @@ def to_raster(obj, ignore_raster_check=False):
     ValueError
         If dataset cannot be converted to raster
     """
-    x_dim, y_dim = _get_spatial_dims()
-    point_dim = _get_point_dim()
-    stacked_point_dim = _get_stacked_point_dim()
-    vertical_dim = _get_vertical_dim()
+    x_dim, y_dim = _xy_dims()
+    point_dim = _point_dim()
+    stacked_point_dim = _stacked_point_dim()
+    vertical_dim = _vertical_dim()
 
     # If object is already raster-like, return early.
     if (is_raster(obj) or is_cuboid(obj)) and _can_be_raster(obj[x_dim], obj[y_dim]):
