@@ -2,14 +2,14 @@
 """
 Height related functions.
 """
-from ._dimensions import _get_vertical_dim
+from ._dimensions import _vertical_dim
 
 
 def has_height_coord(obj):
-    vertical_dim = _get_vertical_dim()
+    vertical_dim = _vertical_dim()
     return vertical_dim in obj.coords
 
 
 def has_height_dim(obj):
-    vertical_dim = _get_vertical_dim()
+    vertical_dim = _vertical_dim()
     return vertical_dim in obj.dims
