@@ -3,46 +3,30 @@
 Public interface to all of the spatial tools in WindKit
 """
 import logging
+
 import numpy as np
-import xarray as xr
 import pyproj
+import xarray as xr
 from scipy.spatial import KDTree
 
 from windkit.geospatial_imports import is_GeoDataFrame, is_GeoSeries
 
+from ..metadata import _GLOBAL_CONVENTIONS, ALL_VARS_META, update_history
 from ._bbox import BBox
-from ._crs import add_crs, get_crs, crs_are_equal
-from ..metadata import ALL_VARS_META, _GLOBAL_CONVENTIONS, update_history
-
-from ._utm import (
-    _utmzone2epsg,
-    _getsitecorners,
-    _mgrs_from_latlon,
-    _get_mgrs_letter_from_lat,
-)
-
-from ._dimensions import (
-    _get_spatial_dims,
-    _get_point_dim,
-    _get_stacked_point_dim,
-    _get_vertical_dim,
-)
-
+from ._crs import add_crs, crs_are_equal, get_crs
+from ._dimensions import _point_dim, _stacked_point_dim, _vertical_dim, _xy_dims
+from ._point import _mask_point, is_point, is_stacked_point, to_point, to_stacked_point
 from ._raster import (
     _can_be_raster,
-    _warp_raster,
-    _mask_raster,
     _clip_to_bbox_raster,
+    _mask_raster,
+    _warp_raster,
     is_raster,
     to_raster,
 )
-
-from ._point import _mask_point, to_point, is_point, is_stacked_point, to_stacked_point
-
 from ._struct import get_spatial_struct
-from ._vertical import has_height_coord, has_height_dim
 from ._vector import _clip_vector
-
+from ._vertical import has_height_coord, has_height_dim
 
 __all__ = [
     "add_crs",
@@ -78,7 +62,7 @@ def are_spatially_equal(obj_a, obj_b):
         True if spatial coords are numpy.allclose
 
     """
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
 
     if obj_a.coords[x_dim].size != obj_b.coords[x_dim].size:
         return False
@@ -163,10 +147,10 @@ def create_dataset(west_east, south_north, height, crs, struct="auto", thresh=1e
             raise ValueError("Cannot identify struct of input data.")
 
     # Get names of dimensions
-    x_dim, y_dim = _get_spatial_dims()
-    z_dim = _get_vertical_dim()
-    pt_dim = _get_point_dim()
-    stacked_pt_dim = _get_stacked_point_dim()
+    x_dim, y_dim = _xy_dims()
+    z_dim = _vertical_dim()
+    pt_dim = _point_dim()
+    stacked_pt_dim = _stacked_point_dim()
 
     if struct.lower() == "cuboid":
 
@@ -312,7 +296,7 @@ def reproject(obj, to_crs, copy=True):
         )
 
     # Get spatial dim names
-    x_dim, y_dim = _get_spatial_dims()
+    x_dim, y_dim = _xy_dims()
 
     # Get output CRS object
     to_crs = pyproj.CRS.from_user_input(to_crs)
@@ -597,7 +581,7 @@ def spatial_stack(
         source.attrs[f"_pwio_was_{orig_format}"] = True
         # Identify 2D variables
         if has_height_dim(source):
-            hgt_dim = _get_vertical_dim()
+            hgt_dim = _vertical_dim()
             for var in source.data_vars:
                 logger.debug("Flagging variable %s as 2d variable", var)
                 source[var].attrs["_pwio_data_is_2d"] = hgt_dim not in source[var].dims
@@ -657,7 +641,7 @@ def spatial_unstack(source):
         del source.attrs["_pwio_was_stacked_point"]
 
     # Transpose the coordinates to match netCDF best practices
-    hgt_dim = _get_vertical_dim()
+    hgt_dim = _vertical_dim()
     if is_stacked_point(source):
         geo_dims_order = (hgt_dim,) + ("stacked_point",)
     elif is_point(source):
@@ -724,8 +708,8 @@ def nearest_points(
     else:
         ds_target = to_point(ds_target)
 
-    arrays = np.array([ds[x].values for x in dims]).T
-    arrays_target = np.array([ds_target[x].values for x in dims]).T
+    arrays = np.array([np.atleast_1d(ds[x].values) for x in dims]).T
+    arrays_target = np.array([np.atleast_1d(ds_target[x].values) for x in dims]).T
     tree = KDTree(arrays)
     dd, ii = tree.query(arrays_target, k=n_nearest)
 
