@@ -26,13 +26,7 @@ from shapely.geometry import LineString, Polygon
 
 from ._vectormap_gml import read_vector_map_gml, write_vectormap_gml
 from ._vectormap_helpers import *
-from ._vectormap_helpers import (
-    _MAP_TYPE_CODES,
-    _is_elev,
-    _is_lc,
-    _is_z0,
-    _z0_to_landcover,
-)
+from ._vectormap_helpers import _MAP_TYPE_CODES, _is_elev, _is_lc, _z0_to_landcover
 from .landcover import LandCoverTable
 from .spatial import BBox
 from .spatial._utm import _utmzone2epsg
@@ -486,7 +480,13 @@ def create_flat_vector_map(
         data[VECTORMAP_ROUR_COL].append(z0_right)
 
     geometry = LineString(
-        [(minx, miny), (maxx, miny), (maxx, maxy), (minx, maxy), (minx, miny),]
+        [
+            (minx, miny),
+            (maxx, miny),
+            (maxx, maxy),
+            (minx, maxy),
+            (minx, miny),
+        ]
     )
 
     data["geometry"].append(geometry)
