@@ -5,19 +5,20 @@ WAsP Workspace module.
 Module containing a class and related methods for importing WAsP workspace
 XML and converting it to WindKit data structures.
 """
-from turtle import up
-import lxml.etree as ET
+import tempfile
 import zipfile
+from pathlib import Path
+
+import lxml.etree as ET
+import numpy as np
 import pandas as pd
+from packaging import version
+
 from .binned_wind_climate import _parse_owc
 from .generalized_wind_climate import _parse_gwc
-from .vector_map import _read_vector_map_combo, _crs_from_map_file
-from .metadata import update_var_attrs, _WEIB_ATTRS, _BWC_ATTRS, update_history
-from .spatial import create_dataset, add_crs
-import tempfile
-from pathlib import Path
-from packaging import version
-import numpy as np
+from .metadata import _BWC_ATTRS, _WEIB_ATTRS, update_history, update_var_attrs
+from .spatial import add_crs, create_dataset
+from .vector_map import _crs_from_map_file, _read_vector_map_combo
 
 _MAP_TYPE_MAPPING = {
     "RoughnessChangeLines": "roughness",
